@@ -1,6 +1,6 @@
-from utils import ParamType
-from utils import utils,CustomTxDecode
-from utils import CustomTx
+from defichainUtils.utils import ParamType
+from defichainUtils.utils import utils,CustomTxDecode
+from defichainUtils.utils import CustomTx
 from dataclasses import dataclass
 
 
